/************************************************************************/
/* requests.c - DNS request management                                   */
/************************************************************************/
/*
 *  Copyright 2021-2023 Todd Shadburn <tshadburn@opencomputingsolutions.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
/************************************************************************/



#include <stdint.h>
#include <stdlib.h>
#include <errno.h>
#include <string.h>
//#include <cutil/slist.h>
#include <requests.h>



request_table_t *request_table_new(uint32_t width)
{
	request_table_t		*t;

	t = calloc(1, sizeof(request_table_t));
	if (!t)
		return NULL;

	t->width = width;
	t->table = calloc(t->width, sizeof(request_t));
	if (!t->table) {
		free(t);
		return NULL;
	}

	return t;
}


int request_table_free(request_table_t *table)
{
	if (!table)
		return EINVAL;
	if (table->table)
		free(table->table);
	free(table);
	return 0;
}

request_t *request_table_get_entry(request_table_t *table, uint16_t id)
{
	if (!table)
		return NULL;
	return &table->table[id];
}

void request_table_clear_entry(request_table_t *table, uint16_t id)
{
	if (table)
		memset(&table->table[id], 0, sizeof(request_t));
	return;
}


void request_reset(request_t *request)
{
	if (!request)
		return;
	request->frontend_fd = -1;
	request->backend_fd = -1;
	request->src_ip = 0;
	request->src_port = 0;
	return;
}


